@@ -11,7 +11,7 @@ use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
 # ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '0.80_06'; # VERSION
+our $VERSION = '0.83_01'; # VERSION
 
 
 has secret => rand;
@@ -19,7 +19,12 @@ has secret => rand;
 
 sub startup {
     my $self = shift;
-    if ($Mojolicious::VERSION >= 2.37) {
+    if ($Mojolicious::VERSION >= 4.0) {
+        $self->hook(before_dispatch => sub {
+          my($c) = @_;
+          Mojo::IOLoop->stream($c->tx->connection)->timeout(3000);
+        });
+    } elsif ($Mojolicious::VERSION >= 2.37) {
         Mojo::IOLoop::Stream->timeout(3000);
     } else {
         Mojo::IOLoop->singleton->connection_timeout(3000);
@@ -70,7 +75,6 @@ sub startup {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -79,7 +83,7 @@ Yars - Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 0.80_06
+version 0.83_01
 
 =head1 DESCRIPTION
 
@@ -257,3 +261,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
